@@ -7,6 +7,7 @@ sjp.emm <- function(fit,
                     plevel = 0.05,
                     title = NULL,
                     geom.colors = "Set1",
+                    geom.size = 0.7,
                     axisTitle.x = NULL,
                     axisTitle.y = NULL,
                     axisLabels.x = NULL,
@@ -22,6 +23,10 @@ sjp.emm <- function(fit,
                     gridBreaksAt = NULL,
                     facet.grid = FALSE,
                     printPlot = TRUE) {
+  # --------------------------------------------------------
+  # check default geom.size
+  # --------------------------------------------------------
+  if (is.null(geom.size)) geom.size = .7
   # ------------------------
   # check if suggested packages are available
   # ------------------------
@@ -35,7 +40,7 @@ sjp.emm <- function(fit,
   # go to sub-function if class = lmerMod
   # -----------------------------------------------------------
   if (any(class(fit) == "lmerMod") || any(class(fit) == "merModLmerTest")) {
-    return(sjp.emm.lmer(fit, swapPredictors, plevel, title, geom.colors,
+    return(sjp.emm.lmer(fit, swapPredictors, plevel, title, geom.colors, geom.size,
                         axisTitle.x, axisTitle.y, axisLabels.x, legendLabels,
                         showValueLabels, valueLabel.digits, showCI, breakTitleAt,
                         breakLegendLabelsAt, axisLimits.y, gridBreaksAt, 
@@ -214,14 +219,17 @@ sjp.emm <- function(fit,
       # get response name, which is variable name
       response.name <- colnames(fit$model)[1]
       # get variable label attribute
-      response.label <- sjmisc:::autoSetVariableLabels(fit$model[[1]])
+      response.label <- sjmisc::get_label(fit$model[[1]], 
+                                          def.value = response.name)
       # check if we have any
       if (is.null(response.label)) response.label <- response.name
       # -----------------------------------------------------------
       # prepare label for x-axix
       # -----------------------------------------------------------
-      # get value label attribute
-      alx <- sjmisc:::autoSetValueLabels(fit$model[[term.pairs[2]]])
+      alx <- sjmisc::get_labels(fit$model[[term.pairs[2]]], 
+                                attr.only = F, 
+                                include.values = NULL, 
+                                include.non.labelled = T)
       # check if we have any
       if (is.null(alx)) alx <- term.pairs[2]
       # -----------------------------------------------------------
@@ -285,7 +293,7 @@ sjp.emm <- function(fit,
       # -----------------------------------------------------------
       baseplot <- baseplot +
         geom_point(aes(x = x, y = y, colour = grp)) +
-        geom_line(aes(x = xn, y = y, colour = grp)) +
+        geom_line(aes(x = xn, y = y, colour = grp), size = geom.size) +
         scale_x_discrete(labels = axisLabels.x)
       # ------------------------------------------------------------
       # plot value labels
@@ -294,7 +302,7 @@ sjp.emm <- function(fit,
         baseplot <- baseplot +
           geom_text(aes(label = round(y, vld), x = x, y = y),
                     vjust = 1.5,
-                    show_guide = FALSE)
+                    show.legend = FALSE)
       }
       # ------------------------------------------------------------------------------------
       # build plot object with theme and labels
@@ -333,13 +341,17 @@ sjp.emm <- function(fit,
 }
 
 
-sjp.emm.lmer <- function(fit, swapPredictors, plevel, title, geom.colors, axisTitle.x,
+sjp.emm.lmer <- function(fit, swapPredictors, plevel, title, geom.colors, geom.size, axisTitle.x,
                          axisTitle.y, axisLabels.x, legendLabels, showValueLabels,
                          valueLabel.digits, showCI, breakTitleAt, breakLegendLabelsAt,
                          axisLimits.y, gridBreaksAt, facet.grid, printPlot) {
   if ((any(class(fit) == "lmerMod") || any(class(fit) == "merModLmerTest")) && !requireNamespace("lmerTest", quietly = TRUE)) {
     stop("Package 'lmerTest' needed for this function to work. Please install it.", call. = FALSE)
   }
+  # --------------------------------------------------------
+  # check default geom.size
+  # --------------------------------------------------------
+  if (is.null(geom.size)) geom.size = .7
   # init vector that saves ggplot objects
   plotlist <- list()
   dflist <- list()
@@ -498,14 +510,18 @@ sjp.emm.lmer <- function(fit, swapPredictors, plevel, title, geom.colors, axisTi
       # get response name, which is variable name
       response.name <- colnames(fit@frame)[1]
       # get variable label attribute
-      response.label <- sjmisc:::autoSetVariableLabels(fit@frame[[1]])
+      response.label <- sjmisc::get_label(fit@frame[[1]], 
+                                          def.value = response.name)
       # check if we have any
       if (is.null(response.label)) response.label <- response.name
       # -----------------------------------------------------------
       # prepare label for x-axix
       # -----------------------------------------------------------
       # get value label attribute
-      alx <- sjmisc:::autoSetValueLabels(fit@frame[[term.pairs[2]]])
+      alx <- sjmisc::get_labels(fit@frame[[term.pairs[2]]], 
+                                attr.only = F, 
+                                include.values = NULL, 
+                                include.non.labelled = T)
       # check if we have any
       if (is.null(alx)) alx <- term.pairs[2]
       # -----------------------------------------------------------
@@ -557,7 +573,7 @@ sjp.emm.lmer <- function(fit, swapPredictors, plevel, title, geom.colors, axisTi
       # -----------------------------------------------------------
       baseplot <- baseplot +
         geom_point(aes(x = x, y = y, colour = grp)) +
-        geom_line(aes(x = xn, y = y, colour = grp)) +
+        geom_line(aes(x = xn, y = y, colour = grp), size = geom.size) +
         scale_x_discrete(labels = axisLabels.x)
       # ------------------------------------------------------------
       # plot value labels
@@ -566,7 +582,7 @@ sjp.emm.lmer <- function(fit, swapPredictors, plevel, title, geom.colors, axisTi
         baseplot <- baseplot +
           geom_text(aes(label = round(y, vld), x = x, y = y),
                     vjust = 1.5,
-                    show_guide = FALSE)
+                    show.legend = FALSE)
       }
       # ------------------------------------------------------------------------------------
       # build plot object with theme and labels
