@@ -230,7 +230,8 @@ sjp.likert <- function(items,
     # if yes, iterate each variable
     for (i in 1:ncol(items)) {
       # retrieve variable name attribute
-      vn <- sjmisc:::autoSetVariableLabels(items[[i]])
+      vn <- sjmisc::get_label(items[[i]],
+                              def.value = get_var_name(deparse(substitute(items[[i]]))))
       # if variable has attribute, add to variableLabel list
       if (!is.null(vn)) {
         axisLabels.y <- c(axisLabels.y, vn)
