@@ -408,7 +408,7 @@ sjp.lmm <- function(...,
     geom_text(aes(label = p, y = upper), 
               position = position_dodge(width = -geom.spacing), 
               hjust = -0.1,
-              show_guide = FALSE) +
+              show.legend = FALSE) +
     # --------------------------------------------------------
     # Intercept-line
     # --------------------------------------------------------
