@@ -178,7 +178,8 @@ sjt.corr <- function(data,
     # if yes, iterate each variable
     for (i in 1:ncol(data)) {
       # retrieve variable name attribute
-      vn <- sjmisc:::autoSetVariableLabels(data[[i]])
+      vn <- sjmisc::get_label(data[[i]],
+                        def.value = get_var_name(deparse(substitute(data[[i]]))))
       # if variable has attribute, add to variableLabel list
       if (!is.null(vn)) {
         varlabels <- c(varlabels, vn)
